@@ -1,7 +1,7 @@
 #########################################################################################
 # Package        HiPi::Interface::MAX7219
 # Description  : Interface to MAX7219 matrix LED driver
-# Copyright    : Copyright (c) 2018 Mark Dootson
+# Copyright    : Copyright (c) 2018-2023 Mark Dootson
 # License      : This is free software; you can redistribute it and/or modify it under
 #                the same terms as the Perl 5 programming language system itself.
 #########################################################################################
@@ -16,7 +16,7 @@ use parent qw( HiPi::Interface );
 use HiPi qw( :max7219 );
 use HiPi::Device::SPI;
 
-our $VERSION ='0.80';
+our $VERSION ='0.89';
 
 __PACKAGE__->create_accessors( qw( ) );
 
@@ -49,7 +49,7 @@ sub new {
     
     my %params = (
         devicename   => '/dev/spidev0.0',
-        speed        => 9600000,  # 9.6 mhz
+        speed        => 8000000,  # 8 mhz
         delay        => 0,
     );
     
